package com.ynet.life.sujrb.cache;

import com.ynet.gene.data.IndexedCollection;
import com.ynet.gene.data.KeyedCollection;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/* loaded from: com_ynet_life_sujrb_cache.jar:com/ynet/life/sujrb/cache/CustomerCacheLoader.class */
public class CustomerCacheLoader extends JdbcCacheLoader {
    @Override // com.ynet.life.sujrb.cache.CacheLoader
    public Map<String, Object> load(String id, String bankid) {
        Map<String, Object> cstObject = new HashMap<>();
        cstObject.putAll(getUserInfo(id, bankid));
        cstObject.putAll(getAccountInfo(id, bankid));
        return cstObject;
    }

    private Map<String, Object> getUserInfo(String id, String bankid) {
        Map<String, Object> m = new HashMap<>();
        Map<String, Object> rs = this.jdbcTemplate.queryForMap("SELECT CIP_NAMECN,CIP_MOBILE,CIP_CTFTYPE,CIP_CTFNO,CIP_ACC_PROTECT,CIP_ADDRESS,CIP_CSTTYPE,CIP_NOTICE_FLAG,CIP_STYLE FROM PB_CSTINF_PRO WHERE CIP_CSTNO = ? AND CIP_BANKID=?", new String[]{id, bankid});
        m.put("customerId", id);
        m.put("bankId", bankid);
        m.put("customerNameCN", rs.get("CIP_NAMECN"));
        m.put("mobileNo", rs.get("CIP_MOBILE"));
        m.put("certType", rs.get("CIP_CTFTYPE"));
        m.put("certNo", rs.get("CIP_CTFNO"));
        return m;
    }

    private Map<String, Object> getAccountInfo(String id, String bankid) {
        IndexedCollection icoll = new IndexedCollection();
        icoll.setId("session_iAccountInfo");
        Map<String, Object> m = new HashMap<>();
        List<Map<String, Object>> li = this.jdbcTemplate.queryForList("SELECT ltrim(rtrim(AIF_ACCNO)) AS ACCOUNTNO,AIF_ACCTYPE AS ACCTYPE,AIF_ALIAS AS ALIAS,AIF_STT AS ACCSTATE,AIF_SIGNFLAG AS SIGNFLAG,AIF_CRYTYPE AS CRYTYPE,AIF_OPENNODE AS OPENNODE,AIF_OPENBRANCH AS OPENBRANCH FROM PB_ACCINF WHERE AIF_CSTNO = ? AND AIF_BANKID=?", new String[]{id, bankid});
        int len = li.size();
        for (int i = 0; i < len; i++) {
            KeyedCollection kcoll = new KeyedCollection();
            Map<String, Object> record = li.get(i);
            kcoll.put("accountNo", record.get("ACCOUNTNO"));
            kcoll.put("accountType", record.get("ACCTYPE"));
            kcoll.put("accountAlias", record.get("ALIAS"));
            kcoll.put("currencyType", record.get("CRYTYPE"));
            kcoll.put("openBranch", record.get("OPENNODE"));
            kcoll.put("branchName", record.get("OPENBRANCH"));
            icoll.addDataElement(kcoll);
        }
        m.put("session_iAccountInfo", icoll);
        return m;
    }

    private Map<String, Object> getCstBsnRight(String id) {
        Map<String, Object> m = new HashMap<>();
        IndexedCollection icoll = new IndexedCollection();
        icoll.setId("session_iCstBsnRight");
        List<Map<String, Object>> li = this.jdbcTemplate.queryForList("SELECT ltrim(rtrim(PCR_ACCNO)) PCR_ACCNO , PCR_BSNTYPE, PCR_BSNNAME, PCR_STT FROM PB_CSTBSN_RIGHT WHERE PCR_CSTNO = ? order by PCR_ACCNO ", new Object[]{id});
        int len = li.size();
        for (int i = 0; i < len; i++) {
            KeyedCollection kcoll = new KeyedCollection();
            Map<String, Object> record = li.get(i);
            kcoll.put("accountNo", record.get("PCR_ACCNO"));
            kcoll.put("bsnType", record.get("PCR_BSNTYPE"));
            kcoll.put("bsnName", record.get("PCR_BSNNAME"));
            kcoll.put("stt", record.get("PCR_STT"));
            icoll.addDataElement(kcoll);
        }
        m.put("session_iCstBsnRight", icoll);
        return m;
    }

    private Map<String, Object> getCreditCurrencyType() {
        String obj;
        Map<String, Object> map = new HashMap<>();
        KeyedCollection currencyKcoll = new KeyedCollection();
        currencyKcoll.setId("session_iCreditCurrencyType");
        List<Map<String, Object>> li = this.jdbcTemplate.queryForList("SELECT CCT_ID , CCT_CURRENCYTYPE ,CCT_ISDOUBLE ,CCT_CURRENCYTYPE1 ,CCT_CURRENCYTYPE2 FROM PB_CREDITCARD_CURRENCYTYPE");
        int len = li.size();
        for (int i = 0; i < len; i++) {
            Map<String, Object> record = li.get(i);
            if (record.get("CCT_ISDOUBLE") != null && record.get("CCT_ISDOUBLE").toString().equals("Y")) {
                obj = record.get("CCT_CURRENCYTYPE1") + "||" + record.get("CCT_CURRENCYTYPE2");
            } else {
                obj = record.get("CCT_CURRENCYTYPE").toString();
            }
            String currency = obj;
            currencyKcoll.put(record.get("CCT_ID").toString(), currency);
        }
        map.put("session_iCreditCurrencyType", currencyKcoll);
        return map;
    }
}
